==> zio-aws-ec2_2.13-5.17.102.9-sources.jar: zio/aws/ec2/model/DescribeFleetError.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeFleetError(
    launchTemplateAndOverrides: Option[
      zio.aws.ec2.model.LaunchTemplateAndOverridesResponse
    ] = None,
    lifecycle: Option[zio.aws.ec2.model.InstanceLifecycle] = None,
    errorCode: Option[String] = None,
    errorMessage: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeFleetError = {
    import DescribeFleetError.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeFleetError
      .builder()
      .optionallyWith(
        launchTemplateAndOverrides.map(value => value.buildAwsValue())
      )(_.launchTemplateAndOverrides)
      .optionallyWith(lifecycle.map(value => value.unwrap))(_.lifecycle)
      .optionallyWith(errorCode.map(value => value: java.lang.String))(
        _.errorCode
      )
      .optionallyWith(errorMessage.map(value => value: java.lang.String))(
        _.errorMessage
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeFleetError.ReadOnly =
    zio.aws.ec2.model.DescribeFleetError.wrap(buildAwsValue())
}
object DescribeFleetError {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeFleetError
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeFleetError =
      zio.aws.ec2.model.DescribeFleetError(
        launchTemplateAndOverrides.map(value => value.asEditable),
        lifecycle.map(value => value),
        errorCode.map(value => value),
        errorMessage.map(value => value)
      )
    def launchTemplateAndOverrides
        : Option[zio.aws.ec2.model.LaunchTemplateAndOverridesResponse.ReadOnly]
    def lifecycle: Option[zio.aws.ec2.model.InstanceLifecycle]
    def errorCode: Option[String]
    def errorMessage: Option[String]
    def getLaunchTemplateAndOverrides: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateAndOverridesResponse.ReadOnly
    ] = AwsError.unwrapOptionField(
      "launchTemplateAndOverrides",
      launchTemplateAndOverrides
    )
    def getLifecycle: ZIO[Any, AwsError, zio.aws.ec2.model.InstanceLifecycle] =
      AwsError.unwrapOptionField("lifecycle", lifecycle)
    def getErrorCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("errorCode", errorCode)
    def getErrorMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("errorMessage", errorMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeFleetError
  ) extends zio.aws.ec2.model.DescribeFleetError.ReadOnly {
    override val launchTemplateAndOverrides: Option[
      zio.aws.ec2.model.LaunchTemplateAndOverridesResponse.ReadOnly
    ] = scala
      .Option(impl.launchTemplateAndOverrides())
      .map(value =>
        zio.aws.ec2.model.LaunchTemplateAndOverridesResponse.wrap(value)
      )
    override val lifecycle: Option[zio.aws.ec2.model.InstanceLifecycle] = scala
      .Option(impl.lifecycle())
      .map(value => zio.aws.ec2.model.InstanceLifecycle.wrap(value))
    override val errorCode: Option[String] =
      scala.Option(impl.errorCode()).map(value => value: String)
    override val errorMessage: Option[String] =
      scala.Option(impl.errorMessage()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeFleetError
  ): zio.aws.ec2.model.DescribeFleetError.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.17.1-sources.jar: zio/aws/ec2/model/DescribeFleetError.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeFleetError(
    launchTemplateAndOverrides: Optional[
      zio.aws.ec2.model.LaunchTemplateAndOverridesResponse
    ] = Optional.Absent,
    lifecycle: Optional[zio.aws.ec2.model.InstanceLifecycle] = Optional.Absent,
    errorCode: Optional[String] = Optional.Absent,
    errorMessage: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeFleetError = {
    import DescribeFleetError.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeFleetError
      .builder()
      .optionallyWith(
        launchTemplateAndOverrides.map(value => value.buildAwsValue())
      )(_.launchTemplateAndOverrides)
      .optionallyWith(lifecycle.map(value => value.unwrap))(_.lifecycle)
      .optionallyWith(errorCode.map(value => value: java.lang.String))(
        _.errorCode
      )
      .optionallyWith(errorMessage.map(value => value: java.lang.String))(
        _.errorMessage
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DescribeFleetError.ReadOnly =
    zio.aws.ec2.model.DescribeFleetError.wrap(buildAwsValue())
}
object DescribeFleetError {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeFleetError
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeFleetError =
      zio.aws.ec2.model.DescribeFleetError(
        launchTemplateAndOverrides.map(value => value.asEditable),
        lifecycle.map(value => value),
        errorCode.map(value => value),
        errorMessage.map(value => value)
      )
    def launchTemplateAndOverrides: Optional[
      zio.aws.ec2.model.LaunchTemplateAndOverridesResponse.ReadOnly
    ]
    def lifecycle: Optional[zio.aws.ec2.model.InstanceLifecycle]
    def errorCode: Optional[String]
    def errorMessage: Optional[String]
    def getLaunchTemplateAndOverrides: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateAndOverridesResponse.ReadOnly
    ] = AwsError.unwrapOptionField(
      "launchTemplateAndOverrides",
      launchTemplateAndOverrides
    )
    def getLifecycle: ZIO[Any, AwsError, zio.aws.ec2.model.InstanceLifecycle] =
      AwsError.unwrapOptionField("lifecycle", lifecycle)
    def getErrorCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("errorCode", errorCode)
    def getErrorMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("errorMessage", errorMessage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeFleetError
  ) extends zio.aws.ec2.model.DescribeFleetError.ReadOnly {
    override val launchTemplateAndOverrides: Optional[
      zio.aws.ec2.model.LaunchTemplateAndOverridesResponse.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.launchTemplateAndOverrides())
      .map(value =>
        zio.aws.ec2.model.LaunchTemplateAndOverridesResponse.wrap(value)
      )
    override val lifecycle: Optional[zio.aws.ec2.model.InstanceLifecycle] =
      zio.aws.core.internal
        .optionalFromNullable(impl.lifecycle())
        .map(value => zio.aws.ec2.model.InstanceLifecycle.wrap(value))
    override val errorCode: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.errorCode())
      .map(value => value: String)
    override val errorMessage: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.errorMessage())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeFleetError
  ): zio.aws.ec2.model.DescribeFleetError.ReadOnly = new Wrapper(impl)
}
